// [License]
// The Ariba-Underlay Copyright
//
// Copyright (c) 2008-2009, Institute of Telematics, Universität Karlsruhe (TH)
//
// Institute of Telematics
// Universität Karlsruhe (TH)
// Zirkel 2, 76128 Karlsruhe
// Germany
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE INSTITUTE OF TELEMATICS ``AS IS'' AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE INSTITUTE OF TELEMATICS OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// The views and conclusions contained in the software and documentation
// are those of the authors and should not be interpreted as representing
// official policies, either expressed or implied, of the Institute of
// Telematics.
// [License]

#include "CommunicationListener.h"

namespace ariba {

CommunicationListener CommunicationListener::DEFAULT;

CommunicationListener::CommunicationListener() {
}

CommunicationListener::~CommunicationListener() {
}

void CommunicationListener::onLinkUp(const LinkID& l, const NodeID& r) {
}

void CommunicationListener::onLinkDown(const LinkID& l, const NodeID& r) {
}

void CommunicationListener::onLinkChanged(const LinkID& l, const NodeID& r) {
}

void CommunicationListener::onLinkFail(const LinkID& l, const NodeID& r) {
    onLinkDown(l, r);
}

bool CommunicationListener::onLinkRequest(const NodeID& remote) {
	return true;
}

void CommunicationListener::onMessage(const DataMessage& msg,
	const NodeID& remote, const LinkID& lnk) {
}

// this implementation provides backward compatibility
// overwrite it to use the new interface
void CommunicationListener::onMessage(reboost::shared_buffer_t message,
        const NodeID& remote,
        const LinkID& lnk,
        const SequenceNumber& seqnum,
        const ariba::overlay::OverlayMsg* overlay_msg)
{
    // copy data
    Data data;
    data.setLength(message.size() * 8);
    memcpy(data.getBuffer(), message.data(), message.size());
    
    // and prepare old-style overlay message
    Message legacy_msg;
    legacy_msg.setPayload(data);
    
    
    // * call legacy handler *
    this->onMessage(legacy_msg, remote, lnk);
}

void CommunicationListener::onKeyValue( const Data& key, const vector<Data>& value ) {
}

bool CommunicationListener::onPing(const NodeID& remote)
{
    return true;
}

void CommunicationListener::onPingLost(const NodeID& remote)
{
}

void CommunicationListener::onPong(const NodeID& remote)
{
}

} // namespace ariba
